summaryrefslogtreecommitdiff
path: root/src/tagline.zig
diff options
context:
space:
mode:
Diffstat (limited to 'src/tagline.zig')
-rw-r--r--src/tagline.zig5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/tagline.zig b/src/tagline.zig
index 032fb5a0..5a9e2346 100644
--- a/src/tagline.zig
+++ b/src/tagline.zig
@@ -116,8 +116,9 @@ pub fn pathPrefix(arena: std.mem.Allocator, pane: *Pane) ![]const u8 {
if (pane.command_status) |n| return std.fmt.allocPrint(arena, "{s} ({s}{s}) exit {d}{s}{s}", .{ (try shownDir(arena, pane)), shown, more, n, gap, id });
return std.fmt.allocPrint(arena, "{s} ({s}{s}) exit ?{s}{s}", .{ (try shownDir(arena, pane)), shown, more, gap, id });
}
- // A bound REPL says what it is bound as, beside its Tty word.
- if (pane.repl != null) {
+ // A bound REPL says what it is bound as, beside its Tty word, while its
+ // program runs: a command REPL whose command exited says no id.
+ if (pane.repl != null and !(pane.command != null and pane.command_done)) {
var idbuf: [48]u8 = undefined;
return std.fmt.allocPrint(arena, "{s} {s}", .{ (try shownDir(arena, pane)), exec.replId(&idbuf, pane) });
}